@@ -1,18 +1,16 @@
-## plot pomp object
-
 setMethod(
           "plot",
           "pomp",
-          function (x, y = NULL, 
+          function (x, y,
                     variables,
                     panel = lines,
                     nc = NULL,
                     yax.flip = FALSE,
-                    mar = c(0, 5.1, 0, if(yax.flip) 5.1 else 2.1),
+                    mar = c(0, 5.1, 0, if (yax.flip) 5.1 else 2.1),
                     oma = c(6, 0, 5, 0),
                     axes = TRUE,
                     ...) {
-            X <- as(x,'data.frame')
+            X <- as(x,"data.frame")
             vars <- names(X)
             tpos <- match("time",vars)
             if (is.na(tpos))
