@@ -24,13 +24,13 @@ void reulermultinom (int m, double size, double *rate, double dt, double *trans)
   GetRNGstate();
   size = rbinom(size,1-exp(-p*dt)); // total number of events
   if (!(R_FINITE(size)))
-    Rprintf("reulermultinom infelicity 1: %lg %lg %lg\n",size,p,dt);
+    warning("reulermultinom: result of binomial draw is not finite");
   m -= 1;
   for (k = 0; k < m; k++) {
     if (rate[k] > p) p = rate[k];
     trans[k] = ((size > 0) && (p > 0)) ? rbinom(size,rate[k]/p) : 0;
     if (!(R_FINITE(size)&&R_FINITE(p)&&R_FINITE(rate[k])&&R_FINITE(trans[k])))
-      Rprintf("reulermultinom infelicity %d: %lg %lg %lg %lg\n",k,size,rate[k]/p,trans[k],dt);
+      warning("reulermultinom: result of binomial draw is not finite");
     size -= trans[k];
     p -= rate[k];
   }
